function [xc,yc,R,Curvt,angle,ncx,ncy,nex,ney,TYPE]=circular_seg3(x,y,xe,ye)
% input: x,y: element end points; xe,ye: element center points;
% output: xc,yc: coords of center of circular boundary on each element;
% R: radius of circular curve of each element;
% Curvt: curvature of each element;
% formula for circle formed by three points are found at:
% http://mathforum.org/dr.math/faq/formulas/faq.analygeom_2.html#twocircles

Nelm=length(xe);

if (length(x)-Nelm)~=1
    disp('Length of vectors do not match!/n');
    return;
end

R=zeros(Nelm,1);
Curvt=zeros(Nelm,1);
xc=zeros(Nelm,1);
yc=zeros(Nelm,1);
angle=zeros(Nelm,3);
ncx=zeros(Nelm,1);
ncy=zeros(Nelm,1);
nex=zeros(Nelm,2);
ney=zeros(Nelm,2);
TYPE=zeros(Nelm,1); % 1:for straight elements; 2:for circular elements.

for Ielm=1:Nelm
    
    x1=x(Ielm); x2=xe(Ielm); x3=x(Ielm+1);
    y1=y(Ielm); y2=ye(Ielm); y3=y(Ielm+1);
    
    matA=[x1,y1,1;x2,y2,1;x3,y3,1]; A=det(matA);
    matD=[x1^2+y1^2,y1,1;x2^2+y2^2,y2,1;x3^2+y3^2,y3,1];
    D=-det(matD);
    matE=[x1^2+y1^2,x1,1;x2^2+y2^2,x2,1;x3^2+y3^2,x3,1];
    E=det(matE);
    matE=[x1^2+y1^2,x1,y1;x2^2+y2^2,x2,y2;x3^2+y3^2,x3,y3];
    F=-det(matE);
    
    temp1=((x2-x1)*(y3-y1)-(y2-y1)*(x3-x1));
    if temp1>1e-15
        alpha=1;
    elseif temp1<-1e-15
        alpha=-1;
    else
        Curvt(Ielm)=0;
        xc(Ielm)=Inf;
        yc(Ielm)=Inf;
        R(Ielm)=Inf;
        TYPE(Ielm)=1;
        
%         if abs(D)<=1e-10
%             angle(Ielm,:)=-pi/2;
%         elseif abs(E)<=1e-10
%             angle(Ielm,:)=-pi;
%         else
%             angle(Ielm,:)=pi-abs(atan(D/E)); % k=-D/E,-1/k=E/D,
%         end
        
        th=atan(E/D);
        angle(Ielm,:)=sign(th)*(abs(th)-pi); 
        ncx(Ielm)=sqrt(D^2/(D^2+E^2));
        ncy(Ielm)=E/D*ncx(Ielm);
        
        nex(Ielm,:)=ncx(Ielm);
        ney(Ielm,:)=ncy(Ielm);
        
        continue;
        
    end
    
    xc(Ielm)=-D/(2*A);
    yc(Ielm)=-E/(2*A);
    R(Ielm)=sqrt(D^2+E^2-4*A*F)/(2*abs(A));
    TYPE(Ielm)=2;
    
    % calculate curvature:
    sintheta=(y2-yc(Ielm))/R(Ielm);
    Curvt(Ielm)=alpha/2*(1/R(Ielm)+sintheta/(yc(Ielm)+R(Ielm)*sintheta));
    
    % calculate angles at mid and end points:
    angle(Ielm,1)=sign(y1-yc(Ielm))*real(acos((x1-xc(Ielm))/R(Ielm)));
    th=angle(Ielm,1);
    nex(Ielm,1)=cos(th); % sign(sin(th))*
    ney(Ielm,1)=sin(th);
    
    temp=(x2-xc(Ielm))*(x1-xc(Ielm))+(y2-yc(Ielm))*(y1-yc(Ielm));
    angle(Ielm,2)=angle(Ielm,1)+alpha*real(acos(temp/(R(Ielm))^2));
    th=angle(Ielm,2);
    ncx(Ielm)=cos(th);
    ncy(Ielm)=sin(th);
        
    temp=(x2-xc(Ielm))*(x3-xc(Ielm))+(y2-yc(Ielm))*(y3-yc(Ielm));
    angle(Ielm,3)=angle(Ielm,2)+alpha*real(acos(temp/(R(Ielm))^2));
    th=angle(Ielm,3);
    nex(Ielm,2)=cos(th);
    ney(Ielm,2)=sin(th);
    
    if abs(x2)<=0.05
        nex(Ielm,:)=nex(Ielm,:).*sign(ney(Ielm,:));
        ney(Ielm,:)=ney(Ielm,:).*sign(ney(Ielm,:));
        ncx(Ielm)=ncx(Ielm)*sign(ncy(Ielm));
        ncy(Ielm)=ncy(Ielm)*sign(ncy(Ielm));
    end
end