function [Ls, Uphi]=BEM_ax_sw_stokes_linear_system_WGM_drop...
    (lamb,nu1,Nelm,xcl,ycl,tcl,xel,yel,tel,xcntr,ycntr,R,Itype,NGL,...
    N_r,N_theta,Rcase,r_min,r_max,theta_min,theta_max,...
    r_mesh,th_mesh,F_mesh)
% Iterate over boundary elements to generate influence matrices
% MATU and MATF, and MATPhi;
% Re-arrange the matrices to generate the linear system that relates
% known and unknown variables.
%
% update based on 'BEM_ax_stokes_linear_system_WGM_drop.m'
% with added governing matrices for swirl (\phi) velocity component
%
% version 10/22/15      author P.Z.

%% influence matrices
% fprintf('Generating Influence matrix...\n');

MATF=zeros(2*Nelm,2*Nelm);
MATU=zeros(2*Nelm,2*Nelm);
MATPhi=zeros(Nelm,Nelm);
Volf=zeros(Nelm,1);

tilt=0.0;

%% discretization of the phi plane for volume integral
% 
Nr=N_r;
Ntheta=N_theta;
r0=r_min/Rcase; 
rn=r_max/Rcase;
theta0=theta_min; 
thetan=theta_max;

% get model GQ points used for all line-integrals:
[Ws,T,TD,X_mod,Y_mod,Vnx,Vny]=...
    bem_ax_crc_GQ_weigtht_array(1.0, theta0, thetan, Ntheta, NGL);

F_GQ=bem_ax_source_GQ(r0,rn,Nr,T,r_mesh,th_mesh,F_mesh);

%% loop over collocation points
for i=1:Nelm
    
    X0 = xcl(i);
    Y0 = ycl(i);
    T0 = tcl(i); % useful only for singular arc element
    
    for j=1:Nelm
        
        X1 = xel(j,1);
        Y1 = yel(j,1);
        
        X2 = xel(j,2);
        Y2 = yel(j,2);
        
        Ityp=Itype(j);
        
        T1=tel(j,1);
        T2=tel(j,2);
        
        if R(j)<1e10
            xcenter=xcntr(j);
            ycenter=ycntr(j);
            amaj=R(j);
            amin=R(j);
        else
            Ityp=1;
            xcenter=0;
            ycenter=0;
            amaj=0;
            amin=0;
        end
        
        Ising = 0;
        if(i==j)
            Ising = 1;
        end
        
        %         [Qxx,Qxy,Qyx,Qyy,Dxx,Dxy,Dyx,Dyy] = ...
        %             prtcl_ax_slp_2 ...
        %             (Iflow ...
        %             ,X0,Y0,T0 ...
        %             ,X1,Y1,T1 ...
        %             ,X2,Y2,T2 ...
        %             ,NGL ...
        %             ,Ising ...
        %             ,Ityp ...  % element type: circle or straight element
        %             ,xcenter,ycenter ...
        %             ,amaj,amin,tilt ... % major and minor axis, tilting angle of ellipse
        %             ,0.0 ... % wall: not used in drop simulations
        %             );
        
        [Qxx,Qxy,Qyx,Qyy,Dxx,Dxy,Dyx,Dyy, Ph] =...
            BEM_ax_sw_sdlp_intgl ...
            ( X0,Y0,T0,X1,Y1,T1,X2,Y2,T2,NGL,Ising,Ityp ...
            ,xcenter,ycenter,amaj,amin,tilt);
        
        MATF(i,     j)      = Qxx;
        MATF(i,     j+Nelm) = Qxy;
        MATF(i+Nelm,j)      = Qyx;
        MATF(i+Nelm,j+Nelm) = Qyy;
        
        MATU(i,     j)      = Dxx;
        MATU(i,     j+Nelm) = Dxy;
        MATU(i+Nelm,j)      = Dyx;
        MATU(i+Nelm,j+Nelm) = Dyy;
        
        MATPhi(i,j) = Ph;
    end
    
    % compute volume integral of the source:
    Volf(i)=bem_ax_stokes_volume_source_intgr...
        (r0,rn,Nr,Ws,TD,F_GQ,X_mod,Y_mod,Vnx,Vny,X0,Y0);
    
end

%% generate linear system
B0=-eye(2*Nelm)+(1-lamb)/(4*pi*(1+lamb)).*MATU;
A0=1/(4*pi*nu1*(1+lamb)).*MATF;

C0=eye(Nelm)-(1-lamb)/(4*pi*(1+lamb)).*MATPhi;

%% invert the matrix so that: velocity=Ls*traction
Ls=-B0\A0;  %

%% compute the velocity phi component
Uphi=C0 \ (   Volf *   1/(4*pi*nu1*(1+lamb))    );
Uphi(Uphi<0)=0.0;