function [u,v,ue,ve,max_u,traction,f_total]=...
    BEM_ax_sw_stokes_solution_WGM_drop...
    (Nelm,Curvt,angc,ang,xcl,ncx,ncy,DP0,Xp,Ls,Uphi,delrho,magnfc)
% obtain the velocity of the interface
% 
% The input collocation matrices are already re-arranged
% and inverted (Ls=-B0\A0) by function 'BEM_ax_stokes_linear_system_WGM_drop.m'
% so that the unknown vector can be obtained by matrix multiplication:
%  ukn = Ls*kn;
% The centrifugal effect is magnified by a factor of 'magnfc' in order to
% reduce computational error; this factor should be considered when
% computing the real interface deformation.
% 
% version 10/26/15      author P.Z.

Curvt(1:2)=Curvt(3);
Curvt(Nelm-1:Nelm)=Curvt(Nelm-2);
%% compute know pressure values
traction=zeros(2*Nelm,1);
%
DPn=interp1(Xp,DP0,xcl); %DPn=DPn.*50;
surftsn=-2*Curvt; %surftsn=surftsn.*0+1;
centfg=0.5*delrho*Uphi.^2;

% magnfc=0.05/max(centfg);

f_total=2.0+surftsn+DPn+centfg*magnfc; %

traction(1:Nelm)=f_total.*ncx;
traction(Nelm+1:2*Nelm)=f_total.*ncy;

%{
figure(56);
clf;
hold on;
plot(0.5*delrho*Uphi.^2,'k.')
plot(abs(surftsn),'b.')
plot(0.5*delrho*Uphi.^2+surftsn,'r.');
%}

%% solve for unknown velocity:

velocity=Ls*traction;

% element center velocity
u=velocity(1:Nelm);
v=velocity(Nelm+1:2*Nelm);

% correct 1st & last point value
u(1)=u(2); u(Nelm)=u(Nelm-1);
v(1)=v(2); v(Nelm)=v(Nelm-1);

% max velocity on interface
max_u=max(sqrt(u.^2+v.^2));

%% For velocity at element edges:
% spline with extended matching boundary:

N_ext=round(Nelm/4);
[ue,ve,sx,sy]=drop_symmetric_extended_spline(angc,u,v,N_ext,ang);

%{
sddx=fnder(sx,2);
ddx=ppval(sddx,ang);

sddy=fnder(sy,2);
ddy=ppval(sddy,ang);

figure(702)
plot(ang,ddx,'m*',ang,ddy,'y*');
%}
