function BEM_ax_sw_stokes_volume_velocity_WGM_drop...
    (Nelm,Iflow,time,u,v,traction,Uphi,nu1,lamb,...
    angc,xel,yel,tel,xcntr,ycntr,R,Itype,...
    N_seed_r,N_seed_th,N_int_r,N_int_th,NGL,filenum,...
    r_mesh,th_mesh,F_mesh,...
    Rcase,r_min,r_max,theta_min,theta_max,flag_plot)
% compute the velocity value at points in the volume;
% the fluid volume is discretized into seeding points in r-theta
% domain; velocity at each seeding point is calculated by boundary
% integral equation;
% the integrals are computed by looping over all elements;
%
% velocity at the boundary are interpolated by the boundary solutions.
%
% version 10/20/15   author P.Z.

%% define coefficients
C_f=1/(8*pi*nu1*lamb);
C_v=(1-lamb)/(8*pi*lamb);

%% solve for x-r component of the velocity field in the volume
fprintf('Solving for U_x, U_r in volume... \n');

% generate seeding points in the fluid domain
rs=linspace(0,1,N_seed_r+1);
rs(N_seed_r+1)=1-1e-3;

tmp_ag=linspace(1,-1,N_seed_th+1);
tmp_ag=abs(tmp_ag).^1.5.*sign(tmp_ag);
thetas=pi/2.*tmp_ag;
thetas=pi/2-thetas';

[R_seed,Th_seed]=meshgrid(rs,thetas);

u_seed=zeros(N_seed_r+1,N_seed_th+1);
v_seed=zeros(N_seed_r+1,N_seed_th+1);

% u_f_seed=zeros(N_seed_r+1,N_seed_th+1);
% v_f_seed=zeros(N_seed_r+1,N_seed_th+1);
% u_u_seed=zeros(N_seed_r+1,N_seed_th+1);
% v_u_seed=zeros(N_seed_r+1,N_seed_th+1);
%% loop over seeding points
Ising = 0;
T0=0; % T0 is not used for nonsingular integrals

tilt=0.0;
wall=0.0;

for Ith=1:N_seed_th+1
    
    for Ir=1:N_seed_r+1
        ri=R_seed(Ir,Ith);
        thi=Th_seed(Ir,Ith);
        
        X0 = ri*cos(thi);
        Y0 = ri*sin(thi);
        
        for j=1:Nelm
            
            X1 = xel(j,1);
            Y1 = yel(j,1);
            
            X2 = xel(j,2);
            Y2 = yel(j,2);
            
            Ityp=Itype(j);
            
            T1=tel(j,1);
            T2=tel(j,2);
            if R(j)<1e10
                xcenter=xcntr(j);
                ycenter=ycntr(j);
                amaj=R(j);
                amin=R(j);
            else
                Ityp=1;
                xcenter=0;
                ycenter=0;
                amaj=0;
                amin=0;
            end
            
            [Qxx,Qxy,Qyx,Qyy,Dxx,Dxy,Dyx,Dyy] = ...
                prtcl_ax_slp_2 ...
                (Iflow ...
                ,X0,Y0,T0 ...
                ,X1,Y1,T1 ...
                ,X2,Y2,T2 ...
                ,NGL ...
                ,Ising ...
                ,Ityp ...  % element type: circle or straight element
                ,xcenter,ycenter ...
                ,amaj,amin,tilt ... % major and minor axis, tilting angle of ellipse
                ,wall ... % wall; not used in droplet simulation
                );
            
            u_seed(Ir,Ith)=u_seed(Ir,Ith)+C_f*( Qxx*traction(j)+Qxy*traction(j+Nelm) ) + ...
                C_v*( Dxx*u(j)+Dxy*v(j)  ); %velocity(j) %velocity(j+Nelm)
            v_seed(Ir,Ith)=v_seed(Ir,Ith)+C_f*( Qyx*traction(j)+Qyy*traction(j+Nelm) ) + ...
                C_v*( Dyx*u(j)+Dyy*v(j)  );
            
%             u_f_seed(Ir,Ith)=u_f_seed(Ir,Ith)+C_f*( Qxx*traction(j)+Qxy*traction(j+Nelm) );
%             u_u_seed(Ir,Ith)=u_f_seed(Ir,Ith)+C_v*( Dxx*u(j)+Dxy*v(j)  );
%             
%             v_f_seed(Ir,Ith)=v_f_seed(Ir,Ith)+C_f*( Qyx*traction(j)+Qyy*traction(j+Nelm) );
%             v_u_seed(Ir,Ith)=v_f_seed(Ir,Ith)+C_v*( Dyx*u(j)+Dyy*v(j)  );
        end % end of iteration over boundary elements
        
    end % end of iteration over r direction
    fprintf('r position: %f \n',ri);
end % end of iteration over theta direction

%% interpolate velocity values on the boundary from boundary solutions
N_ext=round(Nelm/4);
[u_bd,v_bd,~,~]=drop_symmetric_extended_spline(angc,u,v,N_ext,thetas);%(pi/2-thetas)

u_seed(:,N_seed_th+1)=u_bd(:);
v_seed(:,N_seed_th+1)=v_bd(:);

%% plot Ux, Ur data
if flag_plot>0
    rs(N_seed_r+1)=1.0;
    [R_seed,Th_seed]=meshgrid(rs,thetas);
    X_seed=R_seed.*cos(Th_seed);
    Y_seed=R_seed.*sin(Th_seed);
    
    figure(31)
    clf;
    hold on;
    axis equal
    mag_u=sqrt(u_seed.^2+v_seed.^2); %mag_u(:,1)=0;
    [c,h]=contourf(X_seed,Y_seed,mag_u,30);
    set(h, 'linestyle', 'none');
    quiver(X_seed,Y_seed,u_seed,v_seed,'k');
    %                 streamline(X_seed,Y_seed,u_seed,v_seed,0,0.6);
    axis([-1,1,0,1.05]);
    set(gcf,'Color','w');
end

%% save Ux, Ur data
% if flag_save_stream>0
filename=['vel_field_xr_R',filenum,'_t',num2str(time,3),'.mat'];
save(filename,'rs','thetas','N_seed_r','N_seed_th','u_seed','v_seed');

fprintf('U_x, U_r data saved. \n');
% end

%% solve for the u_phi component in the volume
fprintf('Solving for U_phi in volume... \n');
% discretization of the phi plane for volume integral
r0=r_min/Rcase;
rn=r_max/Rcase;
theta0=theta_min;
thetan=theta_max;
% get model GQ points used for all line-integrals:
[Ws,T,TD,X_mod,Y_mod,Vnx,Vny]=...
    bem_ax_crc_GQ_weigtht_array(1.0, theta0, thetan, N_int_th, NGL);

F_GQ=bem_ax_source_GQ(r0,rn,N_int_r,T,r_mesh,th_mesh,F_mesh);

% seeding points in the volume:
%{
vr0=linspace(0,r0,floor(N_seed_r/2)+1);
Vrs=[1e-5,vr0(2:floor(N_seed_r/2)),linspace(r0,rn,floor(N_seed_r/2)+1)];
N_seed_r=length(Vrs)-1; % update the # points in r direction

tmp_ag=linspace(-1,1,N_seed_th+1);
tmp_ag=abs(tmp_ag).^1.2.*sign(tmp_ag);
thetas=pi/2.*tmp_ag+pi/2;
Vths=thetas';
%}

rs(N_seed_r+1)=1-1e-3;
Vrs=rs;
Vths=thetas;

U_phi_volume=zeros(N_seed_th+1,N_seed_r+1);
U_fs=zeros(N_seed_th+1,N_seed_r+1);
U_us=zeros(N_seed_th+1,N_seed_r+1);

[R_seed,Th_seed]=meshgrid(Vrs,Vths); %

%% loop over seeding points in the volume
for Ith=1:N_seed_th+1
    for Ir=1:N_seed_r+1
        Vr=R_seed(Ith,Ir);
        Vtheta=Th_seed(Ith,Ir);
        % seed point
        X0=Vr*cos(Vtheta);
        Y0=Vr*sin(Vtheta);
        
        if Y0<=1e-10
            Y0=1e-5;
        end
        
        % surface double layer integral
        [U,U_f,U_u]=BEM_ax_sw_surface_volume_intgrl...
            (Nelm,X0,Y0,R,xel,yel,tel,Itype,xcntr,ycntr,Uphi,C_f,C_v,...
            r0,rn,N_int_r,Ws,TD,F_GQ,X_mod,Y_mod,Vnx,Vny,NGL);
        
        U_phi_volume(Ith,Ir)=U;
        
        U_fs(Ith,Ir)=U_f;
        U_us(Ith,Ir)=U_u;
    end
    fprintf('theta position: %f \n',Vtheta);
end

%% correct temperature value at equator point/surface
U_surf=interp1([0;angc;pi],[0;Uphi;0],Vths);
U_phi_volume(:,end)=U_surf;

%% save data
filename=['vel_field_phi_R',filenum,'_t',num2str(time,3),'.mat'];
save(filename,'Vrs','Vths','N_seed_r','N_seed_th','U_phi_volume');

fprintf('U_phi data saved. \n');

%% plot Uphi data
if flag_plot>0
%     rs(N_seed_r+1)=1.0;
%     [R_seed,Th_seed]=meshgrid(rs,thetas);
    X_seed=R_seed.*cos(Th_seed);
    Y_seed=R_seed.*sin(Th_seed);
    
    figure(32)
    clf;
    hold on;
    axis equal
    [c,h]=contourf(X_seed,Y_seed,U_phi_volume,30);
    set(h, 'linestyle', 'none');
    axis([-1,1,0,1.05]);
    set(gcf,'Color','w');
    
    %{
        figure(33)
    clf;
    hold on;
    axis equal
    [c,h]=contourf(X_seed,Y_seed,U_fs,30);
    set(h, 'linestyle', 'none');
    axis([-1,1,0,1.05]);
    set(gcf,'Color','w');
    
        figure(34)
    clf;
    hold on;
    axis equal
    [c,h]=contourf(X_seed,Y_seed,U_us,30);
    set(h, 'linestyle', 'none');
    axis([-1,1,0,1.05]);
    set(gcf,'Color','w');
    %}
end
