function [Ws,T,TD,X,Y,Vnx,Vny]=bem_ax_crc_GQ_weigtht_array(R, theta0, thetan, Ntheta, NGL)
% function to generate a series of Gauss Quadrature points
% as well as the weight for GQ points on a circular arc;
%
% Center of each element is assumed to be at the origin (0,0).
%
% Input:
% starting and ending angle of the circular arc;
% radius of the arc;
% number of elements on the arc;
% number of Gauss points on each element;
%
% Output:
% x,y positions of the GQ points locations;
% integral weight of each GQ point;

xcnt=0.0;
ycnt=0.0;

[Z,W]=gauss_leg(NGL); % Gauss quadrature points

theta=linspace(theta0, thetan, Ntheta+1); % element end points

Tm = 0.5*( theta(2:Ntheta+1) + theta(1:Ntheta) ); % element center points
Td = 0.5*( theta(2:Ntheta+1) - theta(1:Ntheta) ); % element half open angle

%% make vector for all GQ points
Zs=repmat(Z(:),Ntheta,1);
Ws=repmat(W(:),Ntheta,1);

TM=repmat(Tm(:)',[NGL,1]); TM=TM(:);
TD=repmat(Td(:)',[NGL,1]); TD=TD(:);

%% values at GQ points
ornt=1.0;
if mean(Td)<0
    ornt = -1.0;
end

T  = TM + TD.*Zs;
cs = cos(T);
sn = sin(T);
X  = xcnt + R*cs;
Y  = ycnt + R*sn;
Vnx = -cs * ornt;  % unit normal vector
Vny = -sn * ornt;  % when arc is counter-clockwise,
% normal vector points away from center

