function M3=bem_ax_sw_stokes_gf_phi_array(X,Y,X0,Y0)
% function to evaluate an array of modified Green function values 
% at locations specified by (x,s); 
% (x0,s0) is the fixed target point.
% 
% Green's function is the phi-component of the axisymmetric Green's
% function, used in the presence of swirling force or velocity.
% 
% this version is modified from bem_ax_laplace_gf_fs_array.m 
% the Green's function is replaced by Stokes Green's function
% 
% version 10/23/15   author:Peng Zhang

%{
dx=x-x0;
ss=s+s0;

factor_xs=dx.^2+ss.^2; % define a new constant vector that will be used multiple times

k2=4*s.*s0./factor_xs;

[F,E]=ellipke(k2); % complete elliptic integral

const=4*factor_xs.^(-3/2);

I30=const.*E./(1-k2);
I31=const.*( -2*F  +  (2-k2).*E./(1-k2) ) ./ k2;
 
G=F./ ( pi.*sqrt(factor_xs) );

Gx=-dx.*I30/(4*pi);
Gs=(s0.*I31-s.*I30)/(4*pi);
%}

eps=0.0000001;

pi2 = 2.0*pi;

% field point on x axis ?
Iaxis = 0;

if(Y0<eps)
    Iaxis = 1;
end

Y2  = Y.*Y;
Y02 = Y0.*Y0;
YY2 = Y2+Y02;
YYP = Y.*Y0; %sigma*sigma0
DY  = Y-Y0;
DY2 = DY.*DY;

%{
if(Iopt > 1)
    Y3   = Y*Y2;
    Y66  = 6.0D0*Y;
    Y03  = Y0*Y02;
end
%}

if(Iaxis==0) % off the axis
%     Y4  = Y2.*Y2;
%     Y04 = Y02.*Y02;
    YYR = sqrt(YYP); % (sigma*sigma0)^1/2
    YY3 = YYR.^3; % (sigma*sigma0)^3/2
%     YY5 = YYR.^5; % (sigma*sigma0)^5/2
    SY  = Y+Y0;
    SY2 = SY.^2;
end

DX   = X-X0;
DX2  = DX.*DX;
% DX4  = DX2.*DX2;
DR2  = DX2+DY2; %(x-x0)^2+(sigma-sigma0)^2
DR   = sqrt(DR2);
DXYY = DX2+YY2; %(x-x0)^2+sigma^2+sigma0^2

%{
if(Iopt > 1)
    Y6DX  = Y66*DX;
    Y6DX2 = Y66*DX2;
    DX3   = DX*DX2;
    Y6DX3 = Y66*DX3;
end
%}

if(Iaxis==0)  %  point x0 off the axis
    
    FC1  = 4.0D0*YYP; % 4(sigma*sigma0)
    FC2  = DX2+SY2; % (x-x0)^2+(sigma+sigma0)^2
    RK2  = FC1./FC2; % k^2
    RK   = sqrt(RK2); % k
    RK3  = RK2.*RK; % k^3
    RK4  = RK2.^2; % k^4
%     RK5  = RK4.*RK; % k^5
    RK2P = 1.0D0-RK2; % k'^2
    
%     [F, E] = ell_int(RK); % for function ell_int, the input should be k
    [F, E] = ellipke(RK2); % for intrinsic MATLAB function, the input is k^2
    
%     RJ10 = 2.0D0 * RK .* F./YYR;
    RJ11 = RK.*(DXYY.*F-(DX2+SY2).*E)./YY3; %YY3=(sigma*sigma0)^3/2 %DXYY=(x-x0)^2+sigma^2+sigma0^2; %DX2=(x-x0)^2; %SY2=(sigma+sigma0)^2
%     RJ30_o = 2.0D0*RK.*E./(YYR.*DR2); % 2kE/((sigma*sigma0)^1/2 * DR2)
%     RJ31_o = RK.*(-F+DXYY.*E./DR2)./YY3;
%     RJ32_o = RK.*(-DXYY.*F+(DX4+2.0*DX2.*YY2+Y4+Y04).*E./DR2)./YY5;
    
    C3=4*RK3./((FC1).^(3/2));  
    Intgl0 = E./(RK2P);
    Intgl2 = E./(RK2.*RK2P) -F./(RK2);
    Intgl4 = E.*(RK2P+1)./(RK4.*RK2P) -2*F./(RK4);
%     Intgl6 = ( (6-4*RK2).*Intgl4 - 3*Intgl2 ) ./ ( 3*RK2 );
%     Intgl6o = numer_ellip_int6(RK2); % use numerical integration
%     Int6 = (8-3*k2-2*k2^2)*E/(3*kp2*k2^3)-(k2+8)*F/(3*k2^3);
    Intgl6 = (8-3*RK2-2*RK2.^2).*E./(3*RK2P.*RK2.^3)-(RK2+8).*F./(3.*RK2.^3);
    
%     fprintf('int6 max diff: %e; \n', max(abs(Intgl6o-Intgl6)) );
%     
%     if max(abs(Intgl6o-Intgl6))>0.1
%         pause(0.001);
%     end
    % need to check these values:
    RJ30 = C3.*Intgl0; 
%     RJ31 = C3.*( 2*Intgl2 - Intgl0);
    RJ32 = C3.*( 4*Intgl4 - 4*Intgl2 + Intgl0);
    RJ33 = C3.*( 8*Intgl6 - 12*Intgl4 + 6*Intgl2 - Intgl0);
    
%     fprintf('Difference: %e, %e, %e. \n',...
%         norm(RJ30-RJ30_o),norm(RJ31-RJ31_o),norm(RJ32-RJ32_o));

    %{
    figure(40)
    hold on;
    plot(norm(RJ30-RJ30_o),'.')
    plot(norm(RJ31-RJ31_o),'.')
    plot(norm(RJ32-RJ32_o),'.')
    %}

    %{
    if(Iopt ~=1)
        
        RL10 = F;
        RL30 = E/RK2P;
        RK6  = RK4*RK2;
        %  RK8  = RK6*RK2
        RL50 =  (2.0D0 * (2.0D0 - RK2)*RL30 - F) / (3.0D0*RK2P);
        RL52 =  (RL50 - RL30)/RK2;
        RL54 =  (F-RL50+2.0*RK2*RL52)/RK4;
        RL56 = -(E-RL50+3.0*RK2*RL52-3.0*RK4*RL54)/ RK6;
        %  PREP = ( 2.0*(2.0-RK2)*E - RK2P*RK2P*F ) / 3.0D0
        %  RL58 = - (PREP - RL50 + 4.0D0 * RK2*RL52 - 6.0D0 * RK4*RL54 ...
        %                          + 4.0D0 * RK6*RL56 ) / RK8;
        FCTR = RK5/(8.0*YY5);
        RJ50 = FCTR * RL50;
        RJ51 = FCTR * (2.0D0 * RL52-RL50);
        RJ52 = FCTR * (4.0D0 * (RL54-RL52)+RL50);
        RJ53 = FCTR * (8.0D0 * RL56 - 12.0D0 *RL54 +6.0D0 * RL52 - RL50);
        %  RJ54 = FCTR * (16.0*RL58 - 32.0*RL56 + 24.0*RL54 ...
        %                  -8.0*RL52 + RL50);
        
    end
    %}

else       %  point x0 on the axis
    
    DR3  = DR2*DR;
%     DR5  = DR3*DR2;
%     RJ10 = pi2/DR;
    RJ11 = 0.0;
    RJ30 = pi2/DR3;
%     RJ31 = 0.0;
    RJ32 = pi/DR3;
    RJ33 = 0.0;
    
    %{
    if(Iopt > 1)
        RJ50 = pi2/DR5;
        RJ51 = 0.0;
        RJ52 = pi/DR5;
        RJ53 = 0.0;
        %  RJ54 = 3.0*pi/(4.0*DR5)
    end
    %}
end


% build the Green's function

% SXX = Y*   (  RJ10 + DX2*RJ30);
% SXY = Y*DX*(Y*RJ30 - Y0 *RJ31);
% SYX = Y*DX*(Y*RJ31 - Y0 *RJ30);
% SYY = Y*   (  RJ11 + YY2*RJ31-YYP*(RJ30+RJ32));

% M3 = Y .* (  RJ11 + YYP.*(RJ30-RJ32) + Y2.*(RJ33-RJ32) );
M3 = Y .* (  RJ11 + YYP.*(RJ30-RJ32)  );
% build the stress tensor
%{
if(Iopt>1)
    
    QXXX = - Y6DX3 * RJ50;
    QXXY = - Y6DX2 * (Y*RJ50 - Y0*RJ51);
    QXYX =   QXXY;
    QXYY = - Y6DX  * (Y02*RJ52+Y2*RJ50 - 2.0*YYP*RJ51);
    QYXX = - Y6DX2 * (Y  *RJ51-Y0*RJ50);
    QYXY = - Y6DX  * ((Y02+Y2)*RJ51 - YYP*(RJ52+RJ50));
    QYYX = QYXY;
    QYYY = - Y66 * ( Y3 * RJ51 - Y03 * RJ52 ...
        - Y*YYP  * (RJ50+2.0*RJ52) + Y0*YYP * (RJ53+2.0*RJ51) );
    
    QZZX = 6 *Y*YYP*DX (RJ52-RJ50);
    QZZY = - Y66 * ( Y3 * RJ51  + Y*YYP  * (RJ50-RJ52) ...
        + Y0*YYP * (RJ53-2.0*RJ51) ); % YYP = Y*Y0;
    
    PXX = QYXX;
    PXY = QYXY;
    PYX = - Y6DX * (Y2*RJ52 - 2.0D0 * YYP*RJ51 + Y02*RJ50);
    PYY = - Y66  * (  Y0*YYP * (2.0D0 * RJ52+RJ50) ...
        - Y03    * RJ51 ...
        - Y *YYP * (2.0*RJ51+RJ53) ...
        + Y3     * RJ52  );
end
%}
