% function to perform volume force
clc;
%% integrate force density over volume
r0=r_min/Rcase;
rn=r_max/Rcase;
theta0=theta_min;
thetan=theta_max;
% get model GQ points used for all line-integrals:
[Ws,T,TD,X_mod,Y_mod,Vnx,Vny]=...
    bem_ax_crc_GQ_weigtht_array(1.0, theta0, thetan, N_int_th, NGL);

F_GQ=bem_ax_source_GQ(r0,rn,N_int_r,T,r_mesh,th_mesh,F_mesh);

dr=(rn-r0)/N_int_r;

%     figure(32);
%     clf;
%     hold on;

NGQ=length(Ws);

if size(F_GQ,2)~=NGQ
    fprintf('Source term F length mismatch! \n');
    return;
end

Iv=0;

for ii=1:N_int_r
    ri=r0+dr*(ii-0.5);
    
    X=X_mod*ri;
    Y=Y_mod*ri;
    DR=TD*ri;
    
    E2=F_GQ(ii,1:NGQ); % distribution of source on GQ points
    
    Iln = E2(:)  .* Y .* Ws.* DR; %

    Iln = sum(Iln);
    
    Iv=Iv+Iln*dr; % sum(integral) in r-direction
end

fprintf('Integral of force density: %e. \n',Iv);

f=Iv;
%% estimate integral of greens function
Xc=0; % center of mode volume 
Yc=0.999;

X0=0.00; % point of singularity
Y0=1; %e-5

Mphi=bem_ax_sw_stokes_gf_phi_array(Xc,Yc,X0,Y0);

Uest=f*Yc*Mphi;

fprintf('estimated Uphi due to force density=%e. \n',Uest);

%%  check accuracy of M_phi calculation
% [SXX,SXY,SYX,SYY,QXXX,QXXY,QXYX,QXYY,QYXX,QYXY,QYYX,QYYY ...
% ,PXX,PXY,PYX,PYY,Iaxis]= sgf_ax_fs (2,Xc,Yc,X0,Y0);

[SXX,SXY,SYX,SYY,QXXX,QXXY,QXYX,QXYY,QYXX,QYXY,QYYX,QYYY ...
    ,QZZX,QZZY,PXX,PXY,PYX,PYY,Iaxis] ...
    = sgf_ax_sw_fs (2,Xc,Yc,X0,Y0);

[Mxx,Mxy,M1,M2,M3,q122,q222,q311,q321,q312,q322,q131,q231,q331,q132,q232,q332]=...
    func_bem_ax_sw_stokes_gf_phi_numer(Xc,Yc,X0,Y0);

fprintf('Difference between numerical and analytic M_phi value: %e. \n', abs(Mphi-M3));

fprintf('Difference between numerical and analytic Qxyy, Qyyy value: %e,%e. \n', abs(q122-QXYY),abs(q222-QYYY));

fprintf('Difference between numerical and analytic q331, q332 value: %e,%e. \n', abs(q331-QZZX),abs(q332-QZZY));

fprintf('Coupling terms in DLP: q131,q231,q132,q232: %e, %e, %e, %e. \n',q131,q231,q132,q232);

fprintf('Coupling terms in DLP: q311,q321,q312,q322: %e, %e, %e, %e. \n',q311,q321,q312,q322);