% test the values of collocation matrix in axisymmetric formulation
%     ( X0,Y0,T0,X1,Y1,T1,X2,Y2,T2,NGL,Ising,Itype ...
%     ,xcntr,ycntr,amaj,amin,tilt)
close all;

%% simulation parameters
Iflow = 1;  % free space

Igeom=1;

NGL   = 8;
mu    = 1.0;
Ux    = 1.0;
wall  = 0.0;

% for volume velocity computations:
% number of seeding points in r and theta directions:
N_seed_r=32;
N_seed_th=32;
% number of integration points in r and theta directions:
N_int_r=64;
N_int_th=64;

[ZZ,WW] = gauss_leg(NGL);

Iopt = 2;

% initialize

Qxx = 0.0;
Qxy = 0.0;
Qyx = 0.0;
Qyy = 0.0;

Dxx = 0.0;
Dxy = 0.0;
Dyx = 0.0;
Dyy = 0.0;


T1=pi/2.5;
T2=pi/2.3;
TD=0.5*(T2-T1);
T0=0.5*(T1+T2);

N=2^8;

Ts=linspace(T1,T2,N);

R=1;
xcntr=0;
ycntr=0;

X0    = xcntr + R*cos(T0);
Y0    = ycntr + R*sin(T0);
vny0  = sin(T0);

Ising=0;

xs = zeros(N,1);
Ph = zeros(N,1);
singln = zeros(N,1);
singr = zeros(N,1);
singq = zeros(N,1);
% loop over Gauss points
for i=1:N
    
    
    T    = Ts(i);
    css  = cos(T);
    snn  = sin(T);
    
    X    = xcntr + R*css;
    Y    = ycntr + R*snn;
    
    vnx  = css;
    vny  = snn;
    
    fcc  = R*TD;        % factor for numerical integration
    
    % Greens function in free space
    
    [Gxx,Gxy ,Gyx,Gyy ...
        ,QXXX,QXXY,QXYX,QXYY ...
        ,QYXX,QYXY,QYYX,QYYY ...
        ,QZZX,QZZY...
        ,~,~,~,~,~] ... %PXX,PXY,PYX,PYY,Iaxis
        = sgf_ax_sw_fs (Iopt,X,Y,X0,Y0);
    
    % subtract off the singularity
    
    
    % single layer integral:
    
    Dists = ( R*(T0-T) )^2;
    singln(i)    = log(Dists);
    singr(i)    = 1./sqrt(Dists);
    
    singq(i) = 0.5*log(Dists)*6*vny/Y;%-0.5*vnx*vny*Y*singr(i);
    
    %         Gxx = Gxx + 2.0D0*DD;
    %         Gyy = Gyy + 2.0D0*DD;
    
    
    % end of subtract off the singularity
    
    %     WI = WW(i)*fcc;
    
    Qxx(i) = Gxx ; %Qxx + * WI
    Qxy = Gxy ;
    Qyx = Gyx ;
    Qyy = Gyy ;
    
    Dxx = (QXXX * vnx + QXXY * vny);
    Dxy = (QXYX * vnx + QXYY * vny);
    
    Dyx = (QYXX * vnx + QYXY * vny);
    Dyy = (QYYX * vnx + QYYY * vny);
    
    Ph(i) = (QZZX * vnx + QZZY * vny);
    
    %     figure(49)
    %     hold on;
    %     plot(X,Qxx(i),'b.',X,Qxx(i)+singln(i),'r.'); %,X,-singln(i),'k.'
    %
    %     figure(50)
    %     hold on
    %     plot(X,Ph(i),'r.'); %X,QZZX,'b.',X,QZZY,'k.',
    
    %     figure(51)
    %     hold on
    %     plot(X,QYYX,'b.',X,QYYY,'k.',X,Dyy,'r.');
    
    xs(i)=X;
end % of Gauss quadrature

%%
fprintf('N=%d; Max |phi| = %f; Max |Gxx|=%f \n',N,max(abs(Ph)),max(abs(Qxx)));

figure(52)
clf;
hold on
plot(xs,Ph,'r.',xs,Ph-3*singln,'g.',xs,Ph-singq,'b.'); %,xs,Ph-2*sing,'r.'


%% singularity of M33
css  = cos(Ts);
snn  = sin(Ts);

X    = xcntr + R*css;
Y    = ycntr + R*snn;
Mphi=bem_ax_sw_stokes_gf_phi_array(X,Y,X0,Y0);

figure(53)
clf;
hold on
plot(xs,Mphi,'r.',xs,Mphi+2*singln','g.'); %,xs,Ph-2*sing,'r.'