function [c,fi_val,f_pt]=get_spherical_coef_Gauss_even(theta,f,N_term,Ng,N_fig)

% get the coefficients for spherical expansion of a give discrete vector f;
% input: function value f evaluated at theta;
% number of termination terms N_term (maximum L value);
% only the even terms are included (symmetric f)
% Gauss Quadrature is used to perform integration

L=0:2:N_term; % numbering of L
N_total=length(L); % total number of terms
N_th=length(theta);
% Ng=20; % number of gauss points
% id=zeros(N_total,N_total);
[Z,Wt]=gauss_quad(Ng);
theta_gauss=(N_th-1)*Ng;
wt_gauss=(N_th-1)*Ng;

Y=zeros(N_total,(N_th-1)*Ng); % pre-allocate legendre value for different L; at gauss points
c=zeros(N_total,1);
f_check=zeros(1,N_th);
%% integration: choose integral method

for ii=1:length(theta)-1
    th0=theta(ii);
    th1=theta(ii+1);
    Lt=(th1-th0)/2;  Lm=(th0+th1)/2;
    theta_gauss((ii-1)*Ng+1:ii*Ng)=Lm+Z*Lt;
    wt_gauss((ii-1)*Ng+1:ii*Ng)=Wt*Lt; % the sum should be element length
end

% get Y at gauss points
X=cos(theta_gauss);
for ii=1:N_total
    n=L(ii);
    F = legendre(n,X,'norm'); %normalized legendre
    Y(ii,:)=F(1,:)./sqrt(2*pi); % first row correspond to m=0; re-normalize in terms of angle
end

% integrate
f_intp=interp1(theta,f,theta_gauss); % interpolate f value at gauss points

for ii=1:N_total
    integrand=Y(ii,:).*f_intp.*sin(theta_gauss);
    c(ii)=2*pi*sum(integrand.*wt_gauss);
end

%% check the sum over the whole curve
X0=cos(theta);

figure(N_fig)
for ii=1:N_total
    n=L(ii);
    F = legendre(n,X0,'norm'); %normalized legendre
    Y0=F(1,:)./sqrt(2*pi);
    f_check=f_check+c(ii).*Y0;
    
end
plot(theta,f,'r-',theta,f_check,'b--','linewidth',2);

%% check the sum at specific points
theta=pi/2;
X0=cos(theta);

fi_val=zeros(N_total,1);
f_pt=0.0;

for ii=1:N_total
    n=L(ii);
    F = legendre(n,X0,'norm'); %normalized legendre
    Y0=F(1,:)./sqrt(2*pi);
    fi_val(ii)=c(ii).*Y0;
    f_pt=f_pt+fi_val(ii);
end

