function Ls=BEM_ax_stokes_linear_system_WGM_drop...
    (lamb,nu1,Nelm,xcl,ycl,tcl,xel,yel,tel,xcntr,ycntr,R,Itype,Iflow,NGL)
% Iterate over boundary elements to generate influence matrices 
% MATU and MATF;
% Re-arrange the matrices to generate the linear system that relates
% known and unknown variables.
% 
% version 10/20/15      author P.Z.

%% influence matrix
% fprintf('Generating Influence matrix...\n');

MATF=zeros(2*Nelm,2*Nelm);
MATU=zeros(2*Nelm,2*Nelm);

tilt=0.0;

for i=1:Nelm
    
    X0 = xcl(i);
    Y0 = ycl(i);
    T0 = tcl(i); % useful only for singular arc element
    
    for j=1:Nelm
        
        X1 = xel(j,1);
        Y1 = yel(j,1);
        
        X2 = xel(j,2);
        Y2 = yel(j,2);
        
        Ityp=Itype(j);
        
        T1=tel(j,1);
        T2=tel(j,2);
        
        if R(j)<1e10
            xcenter=xcntr(j);
            ycenter=ycntr(j);
            amaj=R(j);
            amin=R(j);
        else
            Ityp=1;
            xcenter=0;
            ycenter=0;
            amaj=0;
            amin=0;
        end
        
        Ising = 0;
        if(i==j)
            Ising = 1;
        end

        [Qxx,Qxy,Qyx,Qyy,Dxx,Dxy,Dyx,Dyy] = ...
            ...
            prtcl_ax_slp_2 ...
            (Iflow ...
            ,X0,Y0,T0 ...
            ,X1,Y1,T1 ...
            ,X2,Y2,T2 ...
            ,NGL ...
            ,Ising ...
            ,Ityp ...  % element type: circle or straight element
            ,xcenter,ycenter ...
            ,amaj,amin,tilt ... % major and minor axis, tilting angle of ellipse
            ,0.0 ... % wall: not used in drop simulations
            );
        
        MATF(i,     j)      = Qxx;
        MATF(i,     j+Nelm) = Qxy;
        MATF(i+Nelm,j)      = Qyx;
        MATF(i+Nelm,j+Nelm) = Qyy;
        
        MATU(i,     j)      = Dxx;
        MATU(i,     j+Nelm) = Dxy;
        MATU(i+Nelm,j)      = Dyx;
        MATU(i+Nelm,j+Nelm) = Dyy;
    end
end

%% generate linear system
B0=-eye(2*Nelm)+(1-lamb)/(4*pi*(1+lamb)).*MATU;
A0=1/(4*pi*nu1*(1+lamb)).*MATF;

%% invert the matrix so that: velocity=Ls*traction
Ls=-B0\A0;  % 
