function BEM_ax_stokes_volume_velocity_WGM_drop...
    (Nelm,Iflow,time,u,v,traction,nu1,lamb,angc,xel,yel,tel,...
    xcntr,ycntr,R,Itype,Nr,Ntheta,NGL,filenum,flag_plot)
% compute the velocity value at points in the volume;
% the fluid volume is discretized into seeding points in r-theta
% domain; velocity at each seeding point is calculated by boundary
% integral equation;
% the integrals are computed by looping over all elements;
%
% velocity at the boundary are interpolated by the boundary solutions.
%
% version 10/20/15   author P.Z.

%% discretize the fluid domain

rs=linspace(0,1,Nr+1); rs(Nr+1)=1-1e-3;

tmp_ag=linspace(1,-1,Ntheta+1);
tmp_ag=abs(tmp_ag).^2.*sign(tmp_ag);
thetas=pi/2.*tmp_ag;
thetas=thetas';
thetas=pi/2-thetas';

[R_mesh,Th_mesh]=meshgrid(rs,thetas);

u_mesh=zeros(Nr+1,Ntheta+1);
v_mesh=zeros(Nr+1,Ntheta+1);

%% loop over volume points
Ising = 0;
T0=0; % T0 is not used for nonsingular integrals

C_f=1/(8*pi*nu1*lamb);
C_v=(1-lamb)/(8*pi*lamb);

tilt=0.0;
wall=0.0;

for Ith=1:Ntheta+1
    
    for Ir=1:Nr+1
        ri=R_mesh(Ir,Ith);
        thi=Th_mesh(Ir,Ith);
        
        X0 = ri*cos(thi);
        Y0 = ri*sin(thi);
        
        for j=1:Nelm
            
            X1 = xel(j,1);
            Y1 = yel(j,1);
            
            X2 = xel(j,2);
            Y2 = yel(j,2);
            
            Ityp=Itype(j);
            
            T1=tel(j,1);
            T2=tel(j,2);
            if R(j)<1e10
                xcenter=xcntr(j);
                ycenter=ycntr(j);
                amaj=R(j);
                amin=R(j);
            else
                Ityp=1;
                xcenter=0;
                ycenter=0;
                amaj=0;
                amin=0;
            end
            
            [Qxx,Qxy,Qyx,Qyy,Dxx,Dxy,Dyx,Dyy] = ...
                prtcl_ax_slp_2 ...
                (Iflow ...
                ,X0,Y0,T0 ...
                ,X1,Y1,T1 ...
                ,X2,Y2,T2 ...
                ,NGL ...
                ,Ising ...
                ,Ityp ...  % element type: circle or straight element
                ,xcenter,ycenter ...
                ,amaj,amin,tilt ... % major and minor axis, tilting angle of ellipse
                ,wall ... % wall; not used in droplet simulation
                );
            
            %             MATF(i,     j)      = Qxx;
            %             MATF(i,     j+Nelm) = Qxy;
            %             MATF(i+Nelm,j)      = Qyx;
            %             MATF(i+Nelm,j+Nelm) = Qyy;
            %
            %             MATU(i,     j)      = Dxx;
            %             MATU(i,     j+Nelm) = Dxy;
            %             MATU(i+Nelm,j)      = Dyx;
            %             MATU(i+Nelm,j+Nelm) = Dyy;
            
            u_mesh(Ir,Ith)=u_mesh(Ir,Ith)+C_f*( Qxx*traction(j)+Qxy*traction(j+Nelm) ) + ...
                C_v*( Dxx*u(j)+Dxy*v(j)  ); %velocity(j) %velocity(j+Nelm)
            v_mesh(Ir,Ith)=v_mesh(Ir,Ith)+C_f*( Qyx*traction(j)+Qyy*traction(j+Nelm) ) + ...
                C_v*( Dyx*u(j)+Dyy*v(j)  );
            
        end % end of iteration over boundary elements
        
    end % end of iteration over r direction
        fprintf('r position: %f \n',ri);
end % end of iteration over theta direction

%% interpolate velocity values on the boundary from boundary solutions
N_ext=round(Nelm/4);
[u_bd,v_bd,~,~]=drop_symmetric_extended_spline(angc,u,v,N_ext,thetas);%(pi/2-thetas)

u_mesh(:,Ntheta+1)=u_bd(:);
v_mesh(:,Ntheta+1)=v_bd(:);

%% plot data
if flag_plot>0
    rs(Nr+1)=1.0;
    [R_mesh,Th_mesh]=meshgrid(rs,thetas);
    X_mesh=R_mesh.*cos(Th_mesh);
    Y_mesh=R_mesh.*sin(Th_mesh);
    
    figure(31)
    clf;
    hold on;
    axis equal
    mag_u=sqrt(u_mesh.^2+v_mesh.^2); %mag_u(:,1)=0;
    [~,h]=contourf(X_mesh,Y_mesh,mag_u,30);
    set(h, 'linestyle', 'none');
    quiver(X_mesh,Y_mesh,u_mesh,v_mesh,'k');
    %                 streamline(X_mesh,Y_mesh,u_mesh,v_mesh,0,0.6);
    axis([-1,1,0,1.05]);
    set(gcf,'Color','w');
end

%% save data
% if flag_save_stream>0
filename=['vel_field_R',filenum,'_t',num2str(time,3),'.mat'];
save(filename,'rs','thetas','Nr','Ntheta','u_mesh','v_mesh');
% end