function [angc,sigmas]=func_thermocapillary_stress(Rcase,sigma0)
% calculate the thermocapillary shear stress induced by temperature
% gradient on the interface of the droplet; 
% 
% version 11/29/15   author P.Z.


Tc=374; % C; critical temperature
T0=25; % C; room temperature

%% read temperature data on surface:

dir='temperature_data\';
suffx=[num2str( Rcase ),'.txt'];
fidt=fopen([dir,'Temperature_surf_',suffx]); %

Nelm=fscanf(fidt,' %f ',[1,1]);
angc=fscanf(fidt,'%g ',[1,Nelm]);
T=fscanf(fidt,'%g ',[1,Nelm]);

%% calculate interface tension gradient

T_ratio=(Tc-T)./(Tc-T0); 

sigma=sigma0*T_ratio;

pp_s = csape(angc(:)',sigma(:)','variational');

sigmas = fnval(fnder(pp_s), angc) / (Rcase*1e-6);

%% force sigma gradient symmetry
if mod(Nelm,2)==0
    Nh=Nelm/2;
else
    Nh=(Nelm-1)/2;
end

angc=[angc(1:Nh),pi/2,pi-angc(Nh:-1:1)];
sigmas=[sigmas(1:Nh),0,-sigmas(Nh:-1:1)];